summaryrefslogtreecommitdiff
path: root/src/coremods/core_whois.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/coremods/core_whois.cpp')
-rw-r--r--src/coremods/core_whois.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/coremods/core_whois.cpp b/src/coremods/core_whois.cpp
index 199c9e2ac..0755f66f7 100644
--- a/src/coremods/core_whois.cpp
+++ b/src/coremods/core_whois.cpp
@@ -88,7 +88,7 @@ class CommandWhois : public SplitCommand
void SendChanList(WhoisContextImpl& whois);
public:
/** If true then all opers are shown with a generic 'is an IRC operator' line rather than the oper type. */
bool genericoper;
/** How to handle private/secret channels in the WHOIS response. */
@@ -242,7 +242,7 @@ void CommandWhois::DoWhois(LocalUser* user, User* dest, time_t signon, unsigned
if (dest->IsOper())
{
if (genericoper)
- whois.SendLine(RPL_WHOISOPERATOR, "is an IRC operator");
+ whois.SendLine(RPL_WHOISOPERATOR, "is a server operator");
else
whois.SendLine(RPL_WHOISOPERATOR, InspIRCd::Format("is %s %s on %s", (strchr("AEIOUaeiou",dest->oper->name[0]) ? "an" : "a"), dest->oper->name.c_str(), ServerInstance->Config->Network.c_str()));
}
@@ -88,7 +88,7 @@ class CommandWhois : public SplitCommand
void SendChanList(WhoisContextImpl& whois);
public:
- /** If true then all opers are shown with a generic 'is an IRC operator' line rather than the oper type. */
+ /** If true then all opers are shown with a generic 'is a server operator' line rather than the oper type. */
bool genericoper;
/** How to handle private/secret channels in the WHOIS response. */